/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.ws.integration.jboss40;

// $Id: ServiceRefMetaDataAdapter.java 2598 2007-03-12 10:11:14Z thomas.diesler@jboss.com $

import java.io.IOException;
import java.net.URL;
import java.util.Enumeration;
import java.util.LinkedHashMap;
import java.util.Properties;

import javax.xml.namespace.QName;

import org.jboss.webservice.metadata.serviceref.HandlerMetaData;
import org.jboss.webservice.metadata.serviceref.InitParamMetaData;
import org.jboss.webservice.metadata.serviceref.PortComponentRefMetaData;
import org.jboss.webservice.metadata.serviceref.ServiceRefMetaData;
import org.jboss.ws.core.server.UnifiedDeploymentInfo;
import org.jboss.ws.metadata.j2ee.serviceref.UnifiedCallPropertyMetaData;
import org.jboss.ws.metadata.j2ee.serviceref.UnifiedHandlerMetaData;
import org.jboss.ws.metadata.j2ee.serviceref.UnifiedInitParamMetaData;
import org.jboss.ws.metadata.j2ee.serviceref.UnifiedPortComponentRefMetaData;
import org.jboss.ws.metadata.j2ee.serviceref.UnifiedServiceRefMetaData;

/**
 * Build container independent service ref meta data 
 *
 * @author Thomas.Diesler@jboss.org
 * @since 05-May-2006
 */
public class ServiceRefMetaDataAdapter
{
   public UnifiedServiceRefMetaData buildServiceRefMetaData(UnifiedDeploymentInfo udi, ServiceRefMetaData srmd) throws IOException
   {
      UnifiedServiceRefMetaData usrmd = new UnifiedServiceRefMetaData(udi.vfRoot);
      usrmd.setServiceRefName(srmd.getServiceRefName());
      usrmd.setServiceInterface(srmd.getServiceInterface());
      usrmd.setWsdlFile(srmd.getWsdlFile());
      usrmd.setMappingFile(srmd.getJaxrpcMappingFile());
      usrmd.setServiceQName(srmd.getServiceQName());

      LinkedHashMap<String, UnifiedPortComponentRefMetaData> pcrefs = new LinkedHashMap<String, UnifiedPortComponentRefMetaData>();
      for (PortComponentRefMetaData pcmd : srmd.getPortComponentRefs())
      {
         UnifiedPortComponentRefMetaData upcmd = new UnifiedPortComponentRefMetaData(usrmd);
         upcmd.setServiceEndpointInterface(pcmd.getServiceEndpointInterface());
         upcmd.setPortComponentLink(pcmd.getPortComponentLink());
         Properties callProps = pcmd.getCallProperties();
         if (callProps != null)
         {
            Enumeration<Object> keys = callProps.keys();
            while(keys.hasMoreElements())
            {
               String name = (String)keys.nextElement();
               String value = callProps.getProperty(name);
               upcmd.addCallProperty(new UnifiedCallPropertyMetaData(name, value));
            }
         }
         pcrefs.put(pcmd.getServiceEndpointInterface(), upcmd);
         usrmd.addPortComponentRef(upcmd);
      }

      for (HandlerMetaData hmd : srmd.getHandlers())
      {
         UnifiedHandlerMetaData uhmd = new UnifiedHandlerMetaData(null);
         uhmd.setHandlerName(hmd.getHandlerName());
         uhmd.setHandlerClass(hmd.getHandlerClass());

         for(String portname : hmd.getPortNames())
         {
            uhmd.addPortName(portname);   
         }
         for (InitParamMetaData ipmd : hmd.getInitParams())
         {
            UnifiedInitParamMetaData ip = new UnifiedInitParamMetaData();
            ip.setParamName(ipmd.getParamName());
            ip.setParamValue(ipmd.getParamValue());
            uhmd.addInitParam(ip);
         }
         for (QName soapHeader : hmd.getSoapHeaders())
         {
            uhmd.addSoapHeader(soapHeader);
         }
         for (String soapRole : hmd.getSoapRoles())
         {
            uhmd.addSoapRole(soapRole);
         }
         usrmd.addHandler(uhmd);
      }

      usrmd.setConfigName(srmd.getConfigName());
      usrmd.setConfigFile(srmd.getConfigFile());
      URL wsdlOverride = srmd.getWsdlOverride();
      if (wsdlOverride != null)
         usrmd.setWsdlOverride(wsdlOverride.toExternalForm());

      Properties callProps = srmd.getCallProperties();
      if (callProps != null)
      {
         Enumeration<Object> keys = callProps.keys();
         while(keys.hasMoreElements())
         {
            String name = (String)keys.nextElement();
            String value = callProps.getProperty(name);
            usrmd.addCallProperty(new UnifiedCallPropertyMetaData(name, value));
         }
      }

      return usrmd;
   }
}
